Name:           nuxwdog
Version:        1.0.5
Release:        1%{?dist}
Summary:        Watchdog server to start and stop processes, and prompt for passwords
# The entire source code is LGPLv2 except for the perl module, which is GPL+ or Artistic
License:        LGPLv2 and (GPL+ or Artistic)
URL:            http://www.redhat.com/certificate_system

# For epel5 and fc < 20 compatibility
%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}

BuildRequires:  ant
BuildRequires:  java-devel >= 1:1.6.0
BuildRequires:  jpackage-utils
BuildRequires:  nspr-devel
BuildRequires:  nss-devel
BuildRequires:  pkgconfig
BuildRequires:  libselinux-devel
BuildRequires:  perl-devel
BuildRequires:  perl-generators
BuildRequires:  perl(ExtUtils::MakeMaker)
BuildRequires:  keyutils-libs-devel
BuildRequires:  gcc-c++

Requires:       nss
Requires:       keyutils-libs
Obsoletes:      nuxwdog-client

Source0:        https://github.com/dogtagpki/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz

# Note: there is an rpmlint warning about Nuxwdogclient.so being a private-shared-object-provide
# This would ordinarily be fixed by calling the macro perl_default_filter, but 
# this disables rpms file coloring and makes the package fail multilib tests.

%if 0%{?rhel}
ExcludeArch: ppc ppc64 ppcle ppc64le s390 s390x
%endif

%description
The nuxwdog package supplies the nuxwdog watchdog daemon, 
used to start,stop, prompt for passwords and monitor processes.
It also contains C/C++ and Perl client code to allow clients to
interact with the nuxwdog watchdog daemon.

%package devel
Group:        Development/Libraries
Summary:      Development files for the Nuxwdog Watchdog
Requires:     %{name} = %{version}-%{release}
Obsoletes:    nuxwdog-client-devel

%description devel
The nuxwdog-devel package contains the header files needed to build clients
that call WatchdogClient functions, so that clients can interact with the
nuxwdog watchdog server.

%package client-java
Group:        System Environment/Libraries
Summary:      Nuxwdog Watchdog client JNI Package
Requires:     java-headless >= 1:1.6.0
Requires:     jpackage-utils
Requires:     %{name} = %{version}-%{release}

%description client-java
The nuxwdog-client-java package contains a JNI interface to the nuxwdog 
client code, so that Java clients can interact with the nuxwdog watchdog 
server.

%package client-perl
Summary:      Nuxwdog Watchdog client perl bindings
Requires:     perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
Requires:     %{name} = %{version}-%{release}

%description client-perl
The nuxwdog-client-perl package contains a perl interface to nuxwdog.

%prep
%setup -q -n %{name}-%{version}

sed -i \
  -e 's,^NUXWDOGCLIENT_DOCUMENTATION=${NUXWDOGCLIENT_BUILD_PREFIX}/.*$,NUXWDOGCLIENT_DOCUMENTATION=${NUXWDOGCLIENT_BUILD_PREFIX}%{_pkgdocdir},' setup_package

%build
ant \
    -Dproduct.ui.flavor.prefix="" \
    -Dproduct.prefix="" \
    -Dproduct="nuxwdog" \
    -Dversion="%{version}"
%configure  --disable-static  \
%if 0%{?__isa_bits} == 64
    --enable-64bit \
%endif
    --docdir=%{_pkgdocdir}
make licensedir=%{_pkgdocdir}

%install
make install DESTDIR=%{buildroot} INSTALL="install -p" licensedir=%{_pkgdocdir}
find %{buildroot} -name '*.la' -exec rm -f {} ';'
find %{buildroot}/%{perl_vendorarch} -name .packlist |xargs rm -f {}
find %{buildroot} -type f -name '*.bs' -a -size 0 -exec rm -f {} ';'
find %{buildroot} -name "perllocal.pod" |xargs rm -f {}
%{_fixperms} %{buildroot}/%{perl_vendorarch}/*

mkdir -p %{buildroot}/%{_libdir}/nuxwdog-jni
mv %{buildroot}/%{_libdir}/libnuxwdog-jni.so  %{buildroot}/%{_libdir}/nuxwdog-jni
mv %{buildroot}%{_usr}/jars/nuxwdog.jar %{buildroot}/%{_libdir}/nuxwdog-jni/nuxwdog-%{version}.jar
mkdir -p %{buildroot}%{_jnidir}
cd %{buildroot}/%{_jnidir}
ln -s %{_libdir}/nuxwdog-jni/nuxwdog-%{version}.jar nuxwdog.jar
rm -rf %{buildroot}%{_usr}/jars

%post -p /sbin/ldconfig 

%postun -p /sbin/ldconfig

%files
%_pkgdocdir
%{_bindir}/*
%{_libdir}/libnuxwdog.so.*
%{_mandir}/man1/nuxwdog.1*

%files devel
%{_includedir}/nuxwdog/
%{_libdir}/libnuxwdog.so

%files client-java
%{_libdir}/nuxwdog-jni/
%{_jnidir}/*

%files client-perl
%{perl_vendorarch}/Nuxwdogclient.pm
%{perl_vendorarch}/auto/Nuxwdogclient
%{_mandir}/man3/Nuxwdogclient.3pm*

%changelog
* Thu Aug 16 2018 Dogtag PKI Team (pki-devel@redhat.com) 1.0.5-1
- Fix memory bug due to insufficient memory allocation

* Tue Jul 24 2018 Dogtag PKI Team (pki-devel@redhat.com) 1.0.4-2
- Sync up upstream and restore changes

* Mon Jul 23 2018 Dogtag PKI Team (pki-devel@redhat.com) 1.0.4-1
- Resolves: 1605267 - add gcc-c++ and perl-devel deps

- * Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.3-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Jun 27 2018 Jitka Plesnikova <jplesnik@redhat.com> - 1.0.3-15
- Perl 5.28 rebuild

* Thu Feb 08 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.3-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Jan 17 2018 Ade Lee <alee@redhat.com> 1.0.3-13
- Resolves: 1534030 - add option to set process uid

* Thu Nov 2 2017 Ade Lee <alee@redhat.com> 1.0.3-12
- nuxwdog Pagure Issue #2 - nuxwdog is cutting off long ExeArgs resulting
  in PKI service startup failure

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.3-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.3-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sun Jun 04 2017 Jitka Plesnikova <jplesnik@redhat.com> - 1.0.3-9
- Perl 5.26 rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.3-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sun May 15 2016 Jitka Plesnikova <jplesnik@redhat.com> - 1.0.3-7
- Perl 5.24 rebuild

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.3-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Nov 30 2015 Marcin Juszkiewicz <mjuszkiewicz@redhat.com> - 1.0.3-5
- Use __isa_bits macro instead of list of 64-bit architectures - rhbz#1262388
- drop duplicated libdir in configure call

* Wed Nov 18 2015 Peter Robinson <pbrobinson@fedoraproject.org> 1.0.3-4
- Split out perl bindings into subpackage

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Jun 03 2015 Jitka Plesnikova <jplesnik@redhat.com> - 1.0.3-2
- Perl 5.22 rebuild

* Sun May 10 2015 Ade Lee <alee@redhat.com> 1.0.3-1
- Add systemd support

* Wed Apr 22 2015 Ade Lee <alee@redhat.com> 1.0.2-1
- Allow passwords to be retrieved post-init phase
- Fix null termination issue on returned stored passwords

* Thu Aug 28 2014 Jitka Plesnikova <jplesnik@redhat.com> - 1.0.1-15
- Perl 5.20 rebuild

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Wed Aug 13 2014 Ade Lee <alee@redhat.com> - 1.0.1-13
- Exclude ppcle and ppc64le for rhel build

* Mon Jun 30 2014 Ralf Corsépius <corsepiu@fedoraproject.org> - 1.0.1-12
- Fix UnversionedDocDir-installation issues (FTBFS RHBZ #1106553, RHBZ #992385).
- Let nuxwdog package require perl(:MODULE_COMPAT_..).
- Fix bogus %%changelog date.

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Mar 28 2014 Michael Simacek <msimacek@redhat.com> - 1.0.1-10
- Use Requires: java-headless rebuild (#1067528)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 1.0.1-8
- Perl 5.18 rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Dec 19 2012 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1.0.1-6
- revbump after jnidir change

* Wed Dec 12 2012 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1.0.1-5
- Rebuilt for jpackage-utils changes

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Jan 28 2011 Ade Lee <alee@redhat.com> 1.0.1-1
- Resolves: #643546 - [RFE] Add nuxwdog to RHEL.
- fix file coloring, aliasing problem

* Tue Jan 4 2011 Ade Lee <alee@redhat.com> 1.0.0-16
- Resolves: #643546 - [RFE] Add nuxwdog to RHEL.
- fix build problem

* Tue Jan 4 2011 Ade Lee <alee@redhat.com> 1.0.0-15
- Resolves: #643546 - [RFE] Add nuxwdog to RHEL.
- add needed build requires, requires

* Thu Dec 23 2010 Ade Lee <alee@redhat.com> 1.0.0-14
- Resolves: #643546 - [RFE] Add nuxwdog to RHEL.
- Remove old encryption scheme
- Store passwords in kernel keyring

* Thu Dec 16 2010 Ade Lee <alee@redhat.com> 1.0.0-13
- Resolves: #643546 - [RFE] Add nuxwdog to RHEL.

* Wed Dec 15 2010 Ade Lee <alee@redhat.com> 1.0.0-12
- Resolves: #643546 - [RFE] Add nuxwdog to RHEL. 

* Wed Dec 15 2010 Ade Lee <alee@redhat.com> 1.0.0-11
- Exclude arches for which there is no java

* Wed Dec 8 2010 Ade Lee <alee@redhat.com> 1.0.0-10
- Fixed copyright notices
- Removed versioning for requires
- Fixed library reference in perl build

* Tue Dec 7 2010 Ade Lee <alee@redhat.com> 1.0.0-9
- Fixed macros and copyrights
- Copyrights fixed for perl modules

* Fri Dec 3 2010 Ade Lee <alee@redhat.com> 1.0.0-8
- Spec file modified as per fedora review
- Copyrights fixed for perl modules

* Wed Dec 1 2010 Ade Lee <alee@redhat.com> 1.0.0-7
- Added missing build dependency on MakeMaker
- Removed extra config flags

* Tue Nov 30 2010 Ade Lee <alee@redhat.com> 1.0.0-6
- Restructure rpms
- Fix rpmlint issues

* Fri Sep 10 2010 Ade Lee <alee@redhat.com> 1.0.0-5
- Bumped version to match brew builds
- Bugzilla Bug 630115 - added printMessage() method
 
* Thu Feb 11 2010 Ade Lee <alee@redhat.com> 1.0.0-2
- Initial version in separated repo.

* Tue Dec 1 2009 Ade Lee <alee@redhat.com> 1.0.0-1
- Initial open source version based upon Red Hat
  Certificate System (RHCS) 6.1 uxwdog code.
